@@ -134,6 +134,7 @@ class MainApplication(tk.Frame):
         self.parent.bind("<Control-e>", lambda type: self.load_file("egs"))
         self.parent.bind("<Control-m>", lambda type: self.load_file("measurement"))
         self.parent.bind("<Control-o>", lambda type: self.load_file("simulation"))
+        self.parent.bind("<Control-r>", lambda type: self.load_file("radcalc"))
         self.parent.bind("<Control-s>", self.save_graph)
         self.parent.bind("<Control-p>", lambda type: self.load_file("ptw"))
         self.parent.bind("<Escape>", self.close_file)
@@ -190,6 +191,11 @@ class MainApplication(tk.Frame):
         self.addsimmenu.add_command(
             label="3Ddose", command=lambda: self.load_file("egs"), accelerator="Ctrl+E",
         )
+        self.addsimmenu.add_command(
+            label=self.text.radcalc[self.lang],
+            command=lambda: self.load_file("radcalc"),
+            accelerator="Ctrl+R",
+        )
 
         self.filemenu.add_cascade(
             label=self.text.loadsim[self.lang], menu=self.addsimmenu
@@ -474,7 +480,7 @@ class MainApplication(tk.Frame):
         )
 
         self.normmenu.entryconfig(13, state=tk.DISABLED)
-        self.normmenu.entryconfig(14, state=tk.DISABLED)
+        #self.normmenu.entryconfig(14, state=tk.DISABLED)
         self.normmenu.entryconfig(15, state=tk.DISABLED)
 
         self.menubar.add_command(label=self.text.about[self.lang], command=self.about)
@@ -665,12 +671,13 @@ class MainApplication(tk.Frame):
             filetypes = [(self.text.measurementdata[self.lang], ["txt", ".csv"])]
         elif type == "ptw":
             filetypes = [(self.text.ptw[self.lang], ".mcc")]
+        elif type == "radcalc":
+            filetypes = [(self.text.radcalc[self.lang], [".csv"])]
 
         try:
             initialdir = os.path.dirname(
                 self.profile.get_attribute("recent_files")[0][0]
             )
-            print(initialdir)
         except IndexError:
             initialdir = Path.home()
 
@@ -692,7 +699,7 @@ class MainApplication(tk.Frame):
         self.filemenu.entryconfig(5, state=tk.NORMAL)
         if len(self.filenames) > 2:
             self.normmenu.entryconfig(13, state=tk.DISABLED)
-            self.normmenu.entryconfig(14, state=tk.DISABLED)
+            #self.normmenu.entryconfig(14, state=tk.DISABLED)
             self.normmenu.entryconfig(15, state=tk.DISABLED)
         self.saved = False
 
@@ -730,6 +737,8 @@ class MainApplication(tk.Frame):
                         content = testfile.readlines()[0]
                         if "TOPAS" in content:
                             extensions += ["simulation"]
+                        elif "Machine" in content:
+                            extensions += ["radcalc"]
                         else:
                             extensions += ["measurement"]
                 else:
@@ -754,7 +763,7 @@ class MainApplication(tk.Frame):
         self.filemenu.entryconfig(5, state=tk.NORMAL)
         if len(self.filenames) > 2:
             self.normmenu.entryconfig(13, state=tk.DISABLED)
-            self.normmenu.entryconfig(14, state=tk.DISABLED)
+            #self.normmenu.entryconfig(14, state=tk.DISABLED)
             self.normmenu.entryconfig(15, state=tk.DISABLED)
         self.saved = False
 
@@ -770,7 +779,7 @@ class MainApplication(tk.Frame):
         self.addmeasuremenu.entryconfig(0, state=tk.NORMAL)
         self.addmeasuremenu.entryconfig(1, state=tk.NORMAL)
         self.normmenu.entryconfig(13, state=tk.DISABLED)
-        self.normmenu.entryconfig(14, state=tk.DISABLED)
+        #self.normmenu.entryconfig(14, state=tk.DISABLED)
         self.normmenu.entryconfig(15, state=tk.DISABLED)
         self.parammenu.entryconfig(0, state=tk.NORMAL)
         self.menubar.delete(4, 5)
@@ -932,7 +941,7 @@ class MainApplication(tk.Frame):
             self.diffplot.set(False)
             self.DoseFigureHandler.diffplot = False
             self.normmenu.entryconfig(13, state=tk.DISABLED)
-            self.normmenu.entryconfig(14, state=tk.DISABLED)
+            #self.normmenu.entryconfig(14, state=tk.DISABLED)
             self.normmenu.entryconfig(15, state=tk.DISABLED)
 
         if self.filenames[-1][0].endswith(".mcc") == True:
@@ -974,8 +983,8 @@ class MainApplication(tk.Frame):
         if self.diffplot.get() == True:
             self.normmenu.entryconfig(14, state=tk.NORMAL)
         else:
-            self.normmenu.entryconfig(14, state=tk.DISABLED)
-
+            #self.normmenu.entryconfig(14, state=tk.DISABLED)
+            pass
         self.refresh()
 
         return
@@ -1118,7 +1127,7 @@ class MainApplication(tk.Frame):
 
         if len(self.DoseFigureHandler.plots) >= 2:
             self.normmenu.entryconfig(13, state=tk.DISABLED)
-            self.normmenu.entryconfig(14, state=tk.DISABLED)
+            #self.normmenu.entryconfig(14, state=tk.DISABLED)
             self.normmenu.entryconfig(15, state=tk.DISABLED)
 
         if len(self.DoseFigureHandler.plots) == 2:
